==> quanyi-center-api-1.2.5-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/demand/RemoteDemandGoodsService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.demand;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.demand.DemandGoodsDto;

import java.util.List;

/**
 * 需求商品表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteDemandGoodsService {

    /**
     * 根据需求商品表id查询需求商品详情
     *
     * @param id 需求商品表id
     * @return 需求商品详情
     */
    DemandGoodsDto getDemandGoodsInfo(Long id);

    /**
     * 根据采购单id查询需求商品详情
     *
     * @param demandId 采购单id
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getDemandGoodsListByDemandId(Long demandId);

    /**
     * 根据采购单id查询需求商品详情
     *
     * @param demandId 采购单id
     * @param purchaseStatusList 采购状态
     * @see cn.com.duiba.quanyi.center.api.enums.demand.PurchaseStatusEnum
     * @param goodsStatus 商品状态
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getListByDemandIdPurchaseStatus(Long demandId, List<Integer> purchaseStatusList, Integer goodsStatus);

    /**
     * 根据ID集合查找
     *
     * @param demandGoodIdList ID集合
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getByIdList(List<Long> demandGoodIdList);

    /**
     * 根据需求商品表id更新需求商品
     *
     * @param demandGoodsDto 需求商品信息
     * @return 操作条数
     */
    int updateDemandGoodsById(DemandGoodsDto demandGoodsDto);

    /**
     * 新增需求商品信息
     *
     * @param demandGoodsDto 需求商品信息
     * @return 操作条数
     */
    Long insertDemandGoods(DemandGoodsDto demandGoodsDto);

    /**
     * 根据需求商品单id删除需求商品
     *
     * @param id 需求商品单id
     * @return 操作条数
     */
    int deleteDemandGoods(Long id);

    /**
     * 根据项目商品id查询需求商品信息
     *
     * @param projectGoodsId 项目商品id
     * @return 需求商品信息
     */
    List<DemandGoodsDto> selectByProjectGoodsId(Long projectGoodsId);

}

==> quanyi-center-api-1.2.18-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/demand/RemoteDemandGoodsService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.demand;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.demand.DemandGoodsDto;

import java.util.List;
import java.util.Set;

/**
 * 需求商品表
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemoteDemandGoodsService {

    /**
     * 根据需求商品表id查询需求商品详情
     *
     * @param id 需求商品表id
     * @return 需求商品详情
     */
    DemandGoodsDto getDemandGoodsInfo(Long id);

    /**
     * 根据采购单id查询需求商品详情
     *
     * @param demandId 采购单id
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getDemandGoodsListByDemandId(Long demandId);

    /**
     * 根据采购单id查询需求商品详情
     *
     * @param demandId 采购单id
     * @param purchaseStatusList 采购状态
     * @see cn.com.duiba.quanyi.center.api.enums.demand.PurchaseStatusEnum
     * @param goodsStatus 商品状态
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getListByDemandIdPurchaseStatus(Long demandId, List<Integer> purchaseStatusList, Integer goodsStatus);

    /**
     * 根据ID集合查找
     *
     * @param demandGoodIdList ID集合
     * @return 需求商品详情
     */
    List<DemandGoodsDto> getByIdList(List<Long> demandGoodIdList);

    /**
     * 根据需求商品表id更新需求商品
     *
     * @param demandGoodsDto 需求商品信息
     * @return 操作条数
     */
    int updateDemandGoodsById(DemandGoodsDto demandGoodsDto);

    /**
     * 新增需求商品信息
     *
     * @param demandGoodsDto 需求商品信息
     * @return 操作条数
     */
    Long insertDemandGoods(DemandGoodsDto demandGoodsDto);

    /**
     * 根据需求商品单id删除需求商品
     *
     * @param id 需求商品单id
     * @return 操作条数
     */
    int deleteDemandGoods(Long id);

    /**
     * 根据项目商品id查询需求商品信息
     *
     * @param projectGoodsId 项目商品id
     * @return 需求商品信息
     */
    List<DemandGoodsDto> selectByProjectGoodsId(Long projectGoodsId);

    /**
     * 查询需求商品涉及的需求ID
     * @param ids 主键
     * @return 需求ID
     */
    List<Long> selectDemandIdListByIds(Set<Long> ids);

}
